-file("/usr/local/lib/erlang/lib/parsetools-2.0.12/include/leexinc.hrl", 0).
%% The source of this file is part of leex distribution, as such it
%% has the same Copyright as the other files in the leex
%% distribution. The Copyright is defined in the accompanying file
%% COPYRIGHT. However, the resultant scanner generated by leex is the
%% property of the creator of the scanner and is not covered by that
%% Copyright.

-module(dql_lexer).

-export([string/1,string/2,token/2,token/3,tokens/2,tokens/3]).
-export([format_error/1]).

%% User code. This is placed here to allow extra attributes.
-file("src/dql_lexer.xrl", 73).

-ignore_xref([format_error/1, string/2, token/2, token/3, tokens/2, tokens/3]).

strip(TokenChars,TokenLen) -> lists:sublist(TokenChars, 2, TokenLen - 2).

a(L) -> list_to_atom(L).
i(L) -> list_to_integer(L).
f(L) -> list_to_float(L).
b(L) -> list_to_binary(L).

-file("/usr/local/lib/erlang/lib/parsetools-2.0.12/include/leexinc.hrl", 14).

format_error({illegal,S}) -> ["illegal characters ",io_lib:write_string(S)];
format_error({user,S}) -> S.

string(String) -> string(String, 1).

string(String, Line) -> string(String, Line, String, []).

%% string(InChars, Line, TokenChars, Tokens) ->
%% {ok,Tokens,Line} | {error,ErrorInfo,Line}.
%% Note the line number going into yystate, L0, is line of token
%% start while line number returned is line of token end. We want line
%% of token start.

string([], L, [], Ts) ->                     % No partial tokens!
    {ok,yyrev(Ts),L};
string(Ics0, L0, Tcs, Ts) ->
    case yystate(yystate(), Ics0, L0, 0, reject, 0) of
        {A,Alen,Ics1,L1} ->                  % Accepting end state
            string_cont(Ics1, L1, yyaction(A, Alen, Tcs, L0), Ts);
        {A,Alen,Ics1,L1,_S1} ->              % Accepting transistion state
            string_cont(Ics1, L1, yyaction(A, Alen, Tcs, L0), Ts);
        {reject,_Alen,Tlen,_Ics1,L1,_S1} ->  % After a non-accepting state
            {error,{L0,?MODULE,{illegal,yypre(Tcs, Tlen+1)}},L1};
        {A,Alen,_Tlen,_Ics1,_L1,_S1} ->
            string_cont(yysuf(Tcs, Alen), L0, yyaction(A, Alen, Tcs, L0), Ts)
    end.

%% string_cont(RestChars, Line, Token, Tokens)
%% Test for and remove the end token wrapper. Push back characters
%% are prepended to RestChars.

string_cont(Rest, Line, {token,T}, Ts) ->
    string(Rest, Line, Rest, [T|Ts]);
string_cont(Rest, Line, {token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, [T|Ts]);
string_cont(Rest, Line, {end_token,T}, Ts) ->
    string(Rest, Line, Rest, [T|Ts]);
string_cont(Rest, Line, {end_token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, [T|Ts]);
string_cont(Rest, Line, skip_token, Ts) ->
    string(Rest, Line, Rest, Ts);
string_cont(Rest, Line, {skip_token,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, Ts);
string_cont(_Rest, Line, {error,S}, _Ts) ->
    {error,{Line,?MODULE,{user,S}},Line}.

%% token(Continuation, Chars) ->
%% token(Continuation, Chars, Line) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% Must be careful when re-entering to append the latest characters to the
%% after characters in an accept. The continuation is:
%% {token,State,CurrLine,TokenChars,TokenLen,TokenLine,AccAction,AccLen}

token(Cont, Chars) -> token(Cont, Chars, 1).

token([], Chars, Line) ->
    token(yystate(), Chars, Line, Chars, 0, Line, reject, 0);
token({token,State,Line,Tcs,Tlen,Tline,Action,Alen}, Chars, _) ->
    token(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Action, Alen).

%% token(State, InChars, Line, TokenChars, TokenLen, TokenLine,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% The argument order is chosen to be more efficient.

token(S0, Ics0, L0, Tcs, Tlen0, Tline, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        %% Accepting end state, we have a token.
        {A1,Alen1,Ics1,L1} ->
            token_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline));
        %% Accepting transition state, can take more chars.
        {A1,Alen1,[],L1,S1} ->                  % Need more chars to check
            {more,{token,S1,L1,Tcs,Alen1,Tline,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->               % Take what we got
            token_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline));
        %% After a non-accepting state, maybe reach accept state later.
        {A1,Alen1,Tlen1,[],L1,S1} ->            % Need more chars to check
            {more,{token,S1,L1,Tcs,Tlen1,Tline,A1,Alen1}};
        {reject,_Alen1,Tlen1,eof,L1,_S1} ->     % No token match
            %% Check for partial token which is error.
            Ret = if Tlen1 > 0 -> {error,{Tline,?MODULE,
                                          %% Skip eof tail in Tcs.
                                          {illegal,yypre(Tcs, Tlen1)}},L1};
                     true -> {eof,L1}
                  end,
            {done,Ret,eof};
        {reject,_Alen1,Tlen1,Ics1,L1,_S1} ->    % No token match
            Error = {Tline,?MODULE,{illegal,yypre(Tcs, Tlen1+1)}},
            {done,{error,Error,L1},Ics1};
        {A1,Alen1,_Tlen1,_Ics1,_L1,_S1} ->       % Use last accept match
            token_cont(yysuf(Tcs, Alen1), L0, yyaction(A1, Alen1, Tcs, Tline))
    end.

%% token_cont(RestChars, Line, Token)
%% If we have a token or error then return done, else if we have a
%% skip_token then continue.

token_cont(Rest, Line, {token,T}) ->
    {done,{ok,T,Line},Rest};
token_cont(Rest, Line, {token,T,Push}) ->
    NewRest = Push ++ Rest,
    {done,{ok,T,Line},NewRest};
token_cont(Rest, Line, {end_token,T}) ->
    {done,{ok,T,Line},Rest};
token_cont(Rest, Line, {end_token,T,Push}) ->
    NewRest = Push ++ Rest,
    {done,{ok,T,Line},NewRest};
token_cont(Rest, Line, skip_token) ->
    token(yystate(), Rest, Line, Rest, 0, Line, reject, 0);
token_cont(Rest, Line, {skip_token,Push}) ->
    NewRest = Push ++ Rest,
    token(yystate(), NewRest, Line, NewRest, 0, Line, reject, 0);
token_cont(Rest, Line, {error,S}) ->
    {done,{error,{Line,?MODULE,{user,S}},Line},Rest}.

%% tokens(Continuation, Chars, Line) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% Must be careful when re-entering to append the latest characters to the
%% after characters in an accept. The continuation is:
%% {tokens,State,CurrLine,TokenChars,TokenLen,TokenLine,Tokens,AccAction,AccLen}
%% {skip_tokens,State,CurrLine,TokenChars,TokenLen,TokenLine,Error,AccAction,AccLen}

tokens(Cont, Chars) -> tokens(Cont, Chars, 1).

tokens([], Chars, Line) ->
    tokens(yystate(), Chars, Line, Chars, 0, Line, [], reject, 0);
tokens({tokens,State,Line,Tcs,Tlen,Tline,Ts,Action,Alen}, Chars, _) ->
    tokens(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Ts, Action, Alen);
tokens({skip_tokens,State,Line,Tcs,Tlen,Tline,Error,Action,Alen}, Chars, _) ->
    skip_tokens(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Error, Action, Alen).

%% tokens(State, InChars, Line, TokenChars, TokenLen, TokenLine, Tokens,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.

tokens(S0, Ics0, L0, Tcs, Tlen0, Tline, Ts, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        %% Accepting end state, we have a token.
        {A1,Alen1,Ics1,L1} ->
            tokens_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Ts);
        %% Accepting transition state, can take more chars.
        {A1,Alen1,[],L1,S1} ->                  % Need more chars to check
            {more,{tokens,S1,L1,Tcs,Alen1,Tline,Ts,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->               % Take what we got
            tokens_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Ts);
        %% After a non-accepting state, maybe reach accept state later.
        {A1,Alen1,Tlen1,[],L1,S1} ->            % Need more chars to check
            {more,{tokens,S1,L1,Tcs,Tlen1,Tline,Ts,A1,Alen1}};
        {reject,_Alen1,Tlen1,eof,L1,_S1} ->     % No token match
            %% Check for partial token which is error, no need to skip here.
            Ret = if Tlen1 > 0 -> {error,{Tline,?MODULE,
                                          %% Skip eof tail in Tcs.
                                          {illegal,yypre(Tcs, Tlen1)}},L1};
                     Ts == [] -> {eof,L1};
                     true -> {ok,yyrev(Ts),L1}
                  end,
            {done,Ret,eof};
        {reject,_Alen1,Tlen1,_Ics1,L1,_S1} ->
            %% Skip rest of tokens.
            Error = {L1,?MODULE,{illegal,yypre(Tcs, Tlen1+1)}},
            skip_tokens(yysuf(Tcs, Tlen1+1), L1, Error);
        {A1,Alen1,_Tlen1,_Ics1,_L1,_S1} ->
            Token = yyaction(A1, Alen1, Tcs, Tline),
            tokens_cont(yysuf(Tcs, Alen1), L0, Token, Ts)
    end.

%% tokens_cont(RestChars, Line, Token, Tokens)
%% If we have an end_token or error then return done, else if we have
%% a token then save it and continue, else if we have a skip_token
%% just continue.

tokens_cont(Rest, Line, {token,T}, Ts) ->
    tokens(yystate(), Rest, Line, Rest, 0, Line, [T|Ts], reject, 0);
tokens_cont(Rest, Line, {token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    tokens(yystate(), NewRest, Line, NewRest, 0, Line, [T|Ts], reject, 0);
tokens_cont(Rest, Line, {end_token,T}, Ts) ->
    {done,{ok,yyrev(Ts, [T]),Line},Rest};
tokens_cont(Rest, Line, {end_token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    {done,{ok,yyrev(Ts, [T]),Line},NewRest};
tokens_cont(Rest, Line, skip_token, Ts) ->
    tokens(yystate(), Rest, Line, Rest, 0, Line, Ts, reject, 0);
tokens_cont(Rest, Line, {skip_token,Push}, Ts) ->
    NewRest = Push ++ Rest,
    tokens(yystate(), NewRest, Line, NewRest, 0, Line, Ts, reject, 0);
tokens_cont(Rest, Line, {error,S}, _Ts) ->
    skip_tokens(Rest, Line, {Line,?MODULE,{user,S}}).

%%skip_tokens(InChars, Line, Error) -> {done,{error,Error,Line},Ics}.
%% Skip tokens until an end token, junk everything and return the error.

skip_tokens(Ics, Line, Error) ->
    skip_tokens(yystate(), Ics, Line, Ics, 0, Line, Error, reject, 0).

%% skip_tokens(State, InChars, Line, TokenChars, TokenLen, TokenLine, Tokens,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.

skip_tokens(S0, Ics0, L0, Tcs, Tlen0, Tline, Error, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        {A1,Alen1,Ics1,L1} ->                  % Accepting end state
            skip_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Error);
        {A1,Alen1,[],L1,S1} ->                 % After an accepting state
            {more,{skip_tokens,S1,L1,Tcs,Alen1,Tline,Error,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->
            skip_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Error);
        {A1,Alen1,Tlen1,[],L1,S1} ->           % After a non-accepting state
            {more,{skip_tokens,S1,L1,Tcs,Tlen1,Tline,Error,A1,Alen1}};
        {reject,_Alen1,_Tlen1,eof,L1,_S1} ->
            {done,{error,Error,L1},eof};
        {reject,_Alen1,Tlen1,_Ics1,L1,_S1} ->
            skip_tokens(yysuf(Tcs, Tlen1+1), L1, Error);
        {A1,Alen1,_Tlen1,_Ics1,L1,_S1} ->
            Token = yyaction(A1, Alen1, Tcs, Tline),
            skip_cont(yysuf(Tcs, Alen1), L1, Token, Error)
    end.

%% skip_cont(RestChars, Line, Token, Error)
%% Skip tokens until we have an end_token or error then return done
%% with the original rror.

skip_cont(Rest, Line, {token,_T}, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {token,_T,Push}, Error) ->
    NewRest = Push ++ Rest,
    skip_tokens(yystate(), NewRest, Line, NewRest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {end_token,_T}, Error) ->
    {done,{error,Error,Line},Rest};
skip_cont(Rest, Line, {end_token,_T,Push}, Error) ->
    NewRest = Push ++ Rest,
    {done,{error,Error,Line},NewRest};
skip_cont(Rest, Line, skip_token, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {skip_token,Push}, Error) ->
    NewRest = Push ++ Rest,
    skip_tokens(yystate(), NewRest, Line, NewRest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {error,_S}, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0).

yyrev(List) -> lists:reverse(List).
yyrev(List, Tail) -> lists:reverse(List, Tail).
yypre(List, N) -> lists:sublist(List, N).
yysuf(List, N) -> lists:nthtail(N, List).

%% yystate() -> InitialState.
%% yystate(State, InChars, Line, CurrTokLen, AcceptAction, AcceptLen) ->
%% {Action, AcceptLen, RestChars, Line} |
%% {Action, AcceptLen, RestChars, Line, State} |
%% {reject, AcceptLen, CurrTokLen, RestChars, Line, State} |
%% {Action, AcceptLen, CurrTokLen, RestChars, Line, State}.
%% Generated state transition functions. The non-accepting end state
%% return signal either an unrecognised character or end of current
%% input.

-file("src/dql_lexer.erl", 285).
yystate() -> 107.

yystate(110, [116|Ics], Line, Tlen, _, _) ->
    yystate(106, Ics, Line, Tlen+1, 24, Tlen);
yystate(110, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(110, [84|Ics], Line, Tlen, _, _) ->
    yystate(106, Ics, Line, Tlen+1, 24, Tlen);
yystate(110, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(110, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(110, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 83 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(110, [C|Ics], Line, Tlen, _, _) when C >= 85, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(110, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 115 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(110, [C|Ics], Line, Tlen, _, _) when C >= 117, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(110, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,110};
yystate(109, [37|Ics], Line, Tlen, _, _) ->
    yystate(93, Ics, Line, Tlen+1, 26, Tlen);
yystate(109, [10|Ics], Line, Tlen, _, _) ->
    yystate(109, Ics, Line+1, Tlen+1, 26, Tlen);
yystate(109, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(109, Ics, Line, Tlen+1, 26, Tlen);
yystate(109, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 32 ->
    yystate(109, Ics, Line, Tlen+1, 26, Tlen);
yystate(109, Ics, Line, Tlen, _, _) ->
    {26,Tlen,Ics,Line,109};
yystate(108, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 9, Tlen);
yystate(108, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 9, Tlen);
yystate(108, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 9, Tlen);
yystate(108, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 9, Tlen);
yystate(108, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 9, Tlen);
yystate(108, Ics, Line, Tlen, _, _) ->
    {9,Tlen,Ics,Line,108};
yystate(107, [119|Ics], Line, Tlen, Action, Alen) ->
    yystate(103, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [115|Ics], Line, Tlen, Action, Alen) ->
    yystate(95, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [113|Ics], Line, Tlen, Action, Alen) ->
    yystate(99, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [114|Ics], Line, Tlen, Action, Alen) ->
    yystate(99, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [112|Ics], Line, Tlen, Action, Alen) ->
    yystate(63, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [111|Ics], Line, Tlen, Action, Alen) ->
    yystate(99, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [110|Ics], Line, Tlen, Action, Alen) ->
    yystate(90, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [109|Ics], Line, Tlen, Action, Alen) ->
    yystate(23, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [108|Ics], Line, Tlen, Action, Alen) ->
    yystate(78, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [106|Ics], Line, Tlen, Action, Alen) ->
    yystate(99, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [107|Ics], Line, Tlen, Action, Alen) ->
    yystate(99, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [105|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [104|Ics], Line, Tlen, Action, Alen) ->
    yystate(103, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [103|Ics], Line, Tlen, Action, Alen) ->
    yystate(99, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [102|Ics], Line, Tlen, Action, Alen) ->
    yystate(42, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [101|Ics], Line, Tlen, Action, Alen) ->
    yystate(20, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [100|Ics], Line, Tlen, Action, Alen) ->
    yystate(36, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [99|Ics], Line, Tlen, Action, Alen) ->
    yystate(99, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [98|Ics], Line, Tlen, Action, Alen) ->
    yystate(18, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [97|Ics], Line, Tlen, Action, Alen) ->
    yystate(84, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [83|Ics], Line, Tlen, Action, Alen) ->
    yystate(94, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [78|Ics], Line, Tlen, Action, Alen) ->
    yystate(90, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [77|Ics], Line, Tlen, Action, Alen) ->
    yystate(99, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [76|Ics], Line, Tlen, Action, Alen) ->
    yystate(78, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [74|Ics], Line, Tlen, Action, Alen) ->
    yystate(99, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [75|Ics], Line, Tlen, Action, Alen) ->
    yystate(99, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [73|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [71|Ics], Line, Tlen, Action, Alen) ->
    yystate(99, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [72|Ics], Line, Tlen, Action, Alen) ->
    yystate(99, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [70|Ics], Line, Tlen, Action, Alen) ->
    yystate(42, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [66|Ics], Line, Tlen, Action, Alen) ->
    yystate(18, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [65|Ics], Line, Tlen, Action, Alen) ->
    yystate(45, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(77, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(73, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(77, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [43|Ics], Line, Tlen, Action, Alen) ->
    yystate(73, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [39|Ics], Line, Tlen, Action, Alen) ->
    yystate(81, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [37|Ics], Line, Tlen, Action, Alen) ->
    yystate(93, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(97, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(109, Ics, Line+1, Tlen+1, Action, Alen);
yystate(107, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(109, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(109, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [C|Ics], Line, Tlen, Action, Alen) when C >= 40, C =< 42 ->
    yystate(77, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(49, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [C|Ics], Line, Tlen, Action, Alen) when C >= 67, C =< 69 ->
    yystate(99, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [C|Ics], Line, Tlen, Action, Alen) when C >= 79, C =< 82 ->
    yystate(99, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [C|Ics], Line, Tlen, Action, Alen) when C >= 84, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [C|Ics], Line, Tlen, Action, Alen) when C >= 116, C =< 118 ->
    yystate(99, Ics, Line, Tlen+1, Action, Alen);
yystate(107, [C|Ics], Line, Tlen, Action, Alen) when C >= 120, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, Action, Alen);
yystate(107, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,107};
yystate(106, [101|Ics], Line, Tlen, _, _) ->
    yystate(102, Ics, Line, Tlen+1, 24, Tlen);
yystate(106, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(106, [69|Ics], Line, Tlen, _, _) ->
    yystate(102, Ics, Line, Tlen+1, 24, Tlen);
yystate(106, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(106, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(106, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 68 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(106, [C|Ics], Line, Tlen, _, _) when C >= 70, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(106, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(106, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(106, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,106};
yystate(105, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(105, Ics, Line, Tlen+1, Action, Alen);
yystate(105, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(101, Ics, Line, Tlen+1, Action, Alen);
yystate(105, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(105, Ics, Line+1, Tlen+1, Action, Alen);
yystate(105, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(105, Ics, Line, Tlen+1, Action, Alen);
yystate(105, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(105, Ics, Line, Tlen+1, Action, Alen);
yystate(105, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 45 ->
    yystate(105, Ics, Line, Tlen+1, Action, Alen);
yystate(105, [C|Ics], Line, Tlen, Action, Alen) when C >= 47 ->
    yystate(105, Ics, Line, Tlen+1, Action, Alen);
yystate(105, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,105};
yystate(104, [111|Ics], Line, Tlen, _, _) ->
    yystate(108, Ics, Line, Tlen+1, 24, Tlen);
yystate(104, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(104, [79|Ics], Line, Tlen, _, _) ->
    yystate(108, Ics, Line, Tlen+1, 24, Tlen);
yystate(104, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(104, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(104, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 78 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(104, [C|Ics], Line, Tlen, _, _) when C >= 80, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(104, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 110 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(104, [C|Ics], Line, Tlen, _, _) when C >= 112, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(104, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,104};
yystate(103, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 19, Tlen);
yystate(103, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 19, Tlen);
yystate(103, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 19, Tlen);
yystate(103, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 19, Tlen);
yystate(103, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 19, Tlen);
yystate(103, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,103};
yystate(102, [114|Ics], Line, Tlen, _, _) ->
    yystate(98, Ics, Line, Tlen+1, 24, Tlen);
yystate(102, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(102, [82|Ics], Line, Tlen, _, _) ->
    yystate(98, Ics, Line, Tlen+1, 24, Tlen);
yystate(102, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(102, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(102, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 81 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(102, [C|Ics], Line, Tlen, _, _) when C >= 83, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(102, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 113 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(102, [C|Ics], Line, Tlen, _, _) when C >= 115, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(102, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,102};
yystate(101, Ics, Line, Tlen, _, _) ->
    {23,Tlen,Ics,Line};
yystate(100, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 10, Tlen);
yystate(100, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 10, Tlen);
yystate(100, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 10, Tlen);
yystate(100, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 10, Tlen);
yystate(100, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 10, Tlen);
yystate(100, Ics, Line, Tlen, _, _) ->
    {10,Tlen,Ics,Line,100};
yystate(99, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(99, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(99, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(99, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(99, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(99, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,99};
yystate(98, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 11, Tlen);
yystate(98, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 11, Tlen);
yystate(98, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 11, Tlen);
yystate(98, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 11, Tlen);
yystate(98, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 11, Tlen);
yystate(98, Ics, Line, Tlen, _, _) ->
    {11,Tlen,Ics,Line,98};
yystate(97, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(105, Ics, Line, Tlen+1, Action, Alen);
yystate(97, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(105, Ics, Line+1, Tlen+1, Action, Alen);
yystate(97, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(105, Ics, Line, Tlen+1, Action, Alen);
yystate(97, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(105, Ics, Line, Tlen+1, Action, Alen);
yystate(97, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 45 ->
    yystate(105, Ics, Line, Tlen+1, Action, Alen);
yystate(97, [C|Ics], Line, Tlen, Action, Alen) when C >= 47 ->
    yystate(105, Ics, Line, Tlen+1, Action, Alen);
yystate(97, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,97};
yystate(96, [100|Ics], Line, Tlen, _, _) ->
    yystate(100, Ics, Line, Tlen+1, 24, Tlen);
yystate(96, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(96, [68|Ics], Line, Tlen, _, _) ->
    yystate(100, Ics, Line, Tlen+1, 24, Tlen);
yystate(96, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(96, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(96, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 67 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(96, [C|Ics], Line, Tlen, _, _) when C >= 69, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(96, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 99 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(96, [C|Ics], Line, Tlen, _, _) when C >= 101, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(96, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,96};
yystate(95, [117|Ics], Line, Tlen, _, _) ->
    yystate(91, Ics, Line, Tlen+1, 19, Tlen);
yystate(95, [101|Ics], Line, Tlen, _, _) ->
    yystate(83, Ics, Line, Tlen+1, 19, Tlen);
yystate(95, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 19, Tlen);
yystate(95, [69|Ics], Line, Tlen, _, _) ->
    yystate(83, Ics, Line, Tlen+1, 19, Tlen);
yystate(95, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 19, Tlen);
yystate(95, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 19, Tlen);
yystate(95, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 68 ->
    yystate(99, Ics, Line, Tlen+1, 19, Tlen);
yystate(95, [C|Ics], Line, Tlen, _, _) when C >= 70, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 19, Tlen);
yystate(95, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(99, Ics, Line, Tlen+1, 19, Tlen);
yystate(95, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 116 ->
    yystate(99, Ics, Line, Tlen+1, 19, Tlen);
yystate(95, [C|Ics], Line, Tlen, _, _) when C >= 118, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 19, Tlen);
yystate(95, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,95};
yystate(94, [101|Ics], Line, Tlen, _, _) ->
    yystate(83, Ics, Line, Tlen+1, 24, Tlen);
yystate(94, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(94, [69|Ics], Line, Tlen, _, _) ->
    yystate(83, Ics, Line, Tlen+1, 24, Tlen);
yystate(94, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(94, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(94, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 68 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(94, [C|Ics], Line, Tlen, _, _) when C >= 70, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(94, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(94, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(94, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,94};
yystate(93, [37|Ics], Line, Tlen, _, _) ->
    yystate(93, Ics, Line, Tlen+1, 26, Tlen);
yystate(93, [10|Ics], Line, Tlen, _, _) ->
    yystate(109, Ics, Line+1, Tlen+1, 26, Tlen);
yystate(93, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(93, Ics, Line, Tlen+1, 26, Tlen);
yystate(93, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 32 ->
    yystate(93, Ics, Line, Tlen+1, 26, Tlen);
yystate(93, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 36 ->
    yystate(93, Ics, Line, Tlen+1, 26, Tlen);
yystate(93, [C|Ics], Line, Tlen, _, _) when C >= 38 ->
    yystate(93, Ics, Line, Tlen+1, 26, Tlen);
yystate(93, Ics, Line, Tlen, _, _) ->
    {26,Tlen,Ics,Line,93};
yystate(92, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 3, Tlen);
yystate(92, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 3, Tlen);
yystate(92, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 3, Tlen);
yystate(92, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 3, Tlen);
yystate(92, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 3, Tlen);
yystate(92, Ics, Line, Tlen, _, _) ->
    {3,Tlen,Ics,Line,92};
yystate(91, [109|Ics], Line, Tlen, _, _) ->
    yystate(87, Ics, Line, Tlen+1, 24, Tlen);
yystate(91, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(91, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(91, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(91, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(91, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 108 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(91, [C|Ics], Line, Tlen, _, _) when C >= 110, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(91, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,91};
yystate(90, [111|Ics], Line, Tlen, _, _) ->
    yystate(86, Ics, Line, Tlen+1, 24, Tlen);
yystate(90, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(90, [79|Ics], Line, Tlen, _, _) ->
    yystate(86, Ics, Line, Tlen+1, 24, Tlen);
yystate(90, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(90, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(90, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 78 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(90, [C|Ics], Line, Tlen, _, _) when C >= 80, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(90, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 110 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(90, [C|Ics], Line, Tlen, _, _) when C >= 112, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(90, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,90};
yystate(89, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(89, Ics, Line, Tlen+1, Action, Alen);
yystate(89, [39|Ics], Line, Tlen, Action, Alen) ->
    yystate(85, Ics, Line, Tlen+1, Action, Alen);
yystate(89, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(89, Ics, Line+1, Tlen+1, Action, Alen);
yystate(89, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(89, Ics, Line, Tlen+1, Action, Alen);
yystate(89, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 38 ->
    yystate(89, Ics, Line, Tlen+1, Action, Alen);
yystate(89, [C|Ics], Line, Tlen, Action, Alen) when C >= 40, C =< 45 ->
    yystate(89, Ics, Line, Tlen+1, Action, Alen);
yystate(89, [C|Ics], Line, Tlen, Action, Alen) when C >= 47 ->
    yystate(89, Ics, Line, Tlen+1, Action, Alen);
yystate(89, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,89};
yystate(88, [103|Ics], Line, Tlen, _, _) ->
    yystate(87, Ics, Line, Tlen+1, 24, Tlen);
yystate(88, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(88, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(88, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(88, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(88, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 102 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(88, [C|Ics], Line, Tlen, _, _) when C >= 104, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(88, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,88};
yystate(87, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 18, Tlen);
yystate(87, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 18, Tlen);
yystate(87, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 18, Tlen);
yystate(87, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 18, Tlen);
yystate(87, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 18, Tlen);
yystate(87, Ics, Line, Tlen, _, _) ->
    {18,Tlen,Ics,Line,87};
yystate(86, [119|Ics], Line, Tlen, _, _) ->
    yystate(82, Ics, Line, Tlen+1, 24, Tlen);
yystate(86, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(86, [87|Ics], Line, Tlen, _, _) ->
    yystate(82, Ics, Line, Tlen+1, 24, Tlen);
yystate(86, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(86, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(86, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 86 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(86, [C|Ics], Line, Tlen, _, _) when C >= 88, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(86, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 118 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(86, [C|Ics], Line, Tlen, _, _) when C >= 120, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(86, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,86};
yystate(85, Ics, Line, Tlen, _, _) ->
    {22,Tlen,Ics,Line};
yystate(84, [118|Ics], Line, Tlen, _, _) ->
    yystate(88, Ics, Line, Tlen+1, 24, Tlen);
yystate(84, [116|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(84, [117|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(84, [115|Ics], Line, Tlen, _, _) ->
    yystate(92, Ics, Line, Tlen+1, 24, Tlen);
yystate(84, [110|Ics], Line, Tlen, _, _) ->
    yystate(96, Ics, Line, Tlen+1, 24, Tlen);
yystate(84, [103|Ics], Line, Tlen, _, _) ->
    yystate(104, Ics, Line, Tlen+1, 24, Tlen);
yystate(84, [102|Ics], Line, Tlen, _, _) ->
    yystate(110, Ics, Line, Tlen+1, 24, Tlen);
yystate(84, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(84, [83|Ics], Line, Tlen, _, _) ->
    yystate(92, Ics, Line, Tlen+1, 24, Tlen);
yystate(84, [78|Ics], Line, Tlen, _, _) ->
    yystate(96, Ics, Line, Tlen+1, 24, Tlen);
yystate(84, [71|Ics], Line, Tlen, _, _) ->
    yystate(104, Ics, Line, Tlen+1, 24, Tlen);
yystate(84, [70|Ics], Line, Tlen, _, _) ->
    yystate(110, Ics, Line, Tlen+1, 24, Tlen);
yystate(84, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(84, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(84, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 69 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(84, [C|Ics], Line, Tlen, _, _) when C >= 72, C =< 77 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(84, [C|Ics], Line, Tlen, _, _) when C >= 79, C =< 82 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(84, [C|Ics], Line, Tlen, _, _) when C >= 84, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(84, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 101 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(84, [C|Ics], Line, Tlen, _, _) when C >= 104, C =< 109 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(84, [C|Ics], Line, Tlen, _, _) when C >= 111, C =< 114 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(84, [C|Ics], Line, Tlen, _, _) when C >= 119, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(84, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,84};
yystate(83, [108|Ics], Line, Tlen, _, _) ->
    yystate(79, Ics, Line, Tlen+1, 24, Tlen);
yystate(83, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(83, [76|Ics], Line, Tlen, _, _) ->
    yystate(79, Ics, Line, Tlen+1, 24, Tlen);
yystate(83, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(83, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(83, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 75 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(83, [C|Ics], Line, Tlen, _, _) when C >= 77, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(83, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 107 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(83, [C|Ics], Line, Tlen, _, _) when C >= 109, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(83, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,83};
yystate(82, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 8, Tlen);
yystate(82, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 8, Tlen);
yystate(82, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 8, Tlen);
yystate(82, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 8, Tlen);
yystate(82, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 8, Tlen);
yystate(82, Ics, Line, Tlen, _, _) ->
    {8,Tlen,Ics,Line,82};
yystate(81, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(89, Ics, Line, Tlen+1, Action, Alen);
yystate(81, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(89, Ics, Line+1, Tlen+1, Action, Alen);
yystate(81, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(89, Ics, Line, Tlen+1, Action, Alen);
yystate(81, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 38 ->
    yystate(89, Ics, Line, Tlen+1, Action, Alen);
yystate(81, [C|Ics], Line, Tlen, Action, Alen) when C >= 40, C =< 45 ->
    yystate(89, Ics, Line, Tlen+1, Action, Alen);
yystate(81, [C|Ics], Line, Tlen, Action, Alen) when C >= 47 ->
    yystate(89, Ics, Line, Tlen+1, Action, Alen);
yystate(81, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,81};
yystate(80, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 14, Tlen);
yystate(80, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 14, Tlen);
yystate(80, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 14, Tlen);
yystate(80, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 14, Tlen);
yystate(80, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 14, Tlen);
yystate(80, Ics, Line, Tlen, _, _) ->
    {14,Tlen,Ics,Line,80};
yystate(79, [101|Ics], Line, Tlen, _, _) ->
    yystate(75, Ics, Line, Tlen+1, 24, Tlen);
yystate(79, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(79, [69|Ics], Line, Tlen, _, _) ->
    yystate(75, Ics, Line, Tlen+1, 24, Tlen);
yystate(79, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(79, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(79, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 68 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(79, [C|Ics], Line, Tlen, _, _) when C >= 70, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(79, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(79, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(79, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,79};
yystate(78, [105|Ics], Line, Tlen, _, _) ->
    yystate(74, Ics, Line, Tlen+1, 24, Tlen);
yystate(78, [97|Ics], Line, Tlen, _, _) ->
    yystate(62, Ics, Line, Tlen+1, 24, Tlen);
yystate(78, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(78, [73|Ics], Line, Tlen, _, _) ->
    yystate(74, Ics, Line, Tlen+1, 24, Tlen);
yystate(78, [65|Ics], Line, Tlen, _, _) ->
    yystate(62, Ics, Line, Tlen+1, 24, Tlen);
yystate(78, [64|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(78, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(78, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(78, [C|Ics], Line, Tlen, _, _) when C >= 66, C =< 72 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(78, [C|Ics], Line, Tlen, _, _) when C >= 74, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(78, [C|Ics], Line, Tlen, _, _) when C >= 98, C =< 104 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(78, [C|Ics], Line, Tlen, _, _) when C >= 106, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(78, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,78};
yystate(77, Ics, Line, Tlen, _, _) ->
    {25,Tlen,Ics,Line};
yystate(76, [101|Ics], Line, Tlen, _, _) ->
    yystate(80, Ics, Line, Tlen+1, 24, Tlen);
yystate(76, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(76, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(76, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(76, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(76, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(76, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(76, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,76};
yystate(75, [99|Ics], Line, Tlen, _, _) ->
    yystate(71, Ics, Line, Tlen+1, 24, Tlen);
yystate(75, [97|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(75, [98|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(75, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(75, [67|Ics], Line, Tlen, _, _) ->
    yystate(71, Ics, Line, Tlen+1, 24, Tlen);
yystate(75, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(75, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(75, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 66 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(75, [C|Ics], Line, Tlen, _, _) when C >= 68, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(75, [C|Ics], Line, Tlen, _, _) when C >= 100, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(75, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,75};
yystate(74, [107|Ics], Line, Tlen, _, _) ->
    yystate(70, Ics, Line, Tlen+1, 24, Tlen);
yystate(74, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(74, [75|Ics], Line, Tlen, _, _) ->
    yystate(70, Ics, Line, Tlen+1, 24, Tlen);
yystate(74, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(74, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(74, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 74 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(74, [C|Ics], Line, Tlen, _, _) when C >= 76, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(74, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 106 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(74, [C|Ics], Line, Tlen, _, _) when C >= 108, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(74, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,74};
yystate(73, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(49, Ics, Line, Tlen+1, Action, Alen);
yystate(73, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,73};
yystate(72, [116|Ics], Line, Tlen, _, _) ->
    yystate(76, Ics, Line, Tlen+1, 24, Tlen);
yystate(72, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(72, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(72, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(72, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(72, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 115 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(72, [C|Ics], Line, Tlen, _, _) when C >= 117, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(72, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,72};
yystate(71, [116|Ics], Line, Tlen, _, _) ->
    yystate(67, Ics, Line, Tlen+1, 24, Tlen);
yystate(71, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(71, [84|Ics], Line, Tlen, _, _) ->
    yystate(67, Ics, Line, Tlen+1, 24, Tlen);
yystate(71, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(71, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(71, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 83 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(71, [C|Ics], Line, Tlen, _, _) when C >= 85, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(71, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 115 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(71, [C|Ics], Line, Tlen, _, _) when C >= 117, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(71, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,71};
yystate(70, [101|Ics], Line, Tlen, _, _) ->
    yystate(66, Ics, Line, Tlen+1, 24, Tlen);
yystate(70, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(70, [69|Ics], Line, Tlen, _, _) ->
    yystate(66, Ics, Line, Tlen+1, 24, Tlen);
yystate(70, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(70, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(70, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 68 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(70, [C|Ics], Line, Tlen, _, _) when C >= 70, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(70, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(70, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(70, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,70};
yystate(69, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(65, Ics, Line, Tlen+1, Action, Alen);
yystate(69, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,69};
yystate(68, [97|Ics], Line, Tlen, _, _) ->
    yystate(72, Ics, Line, Tlen+1, 24, Tlen);
yystate(68, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(68, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(68, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(68, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(68, [C|Ics], Line, Tlen, _, _) when C >= 98, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(68, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,68};
yystate(67, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 0, Tlen);
yystate(67, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 0, Tlen);
yystate(67, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 0, Tlen);
yystate(67, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 0, Tlen);
yystate(67, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 0, Tlen);
yystate(67, Ics, Line, Tlen, _, _) ->
    {0,Tlen,Ics,Line,67};
yystate(66, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 7, Tlen);
yystate(66, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 7, Tlen);
yystate(66, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 7, Tlen);
yystate(66, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 7, Tlen);
yystate(66, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 7, Tlen);
yystate(66, Ics, Line, Tlen, _, _) ->
    {7,Tlen,Ics,Line,66};
yystate(65, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(65, Ics, Line, Tlen+1, 21, Tlen);
yystate(65, Ics, Line, Tlen, _, _) ->
    {21,Tlen,Ics,Line,65};
yystate(64, [118|Ics], Line, Tlen, _, _) ->
    yystate(68, Ics, Line, Tlen+1, 24, Tlen);
yystate(64, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(64, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(64, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(64, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(64, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 117 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(64, [C|Ics], Line, Tlen, _, _) when C >= 119, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(64, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,64};
yystate(63, [101|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 24, Tlen);
yystate(63, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(63, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(63, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(63, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(63, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(63, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(63, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,63};
yystate(62, [115|Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen+1, 24, Tlen);
yystate(62, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(62, [83|Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen+1, 24, Tlen);
yystate(62, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(62, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(62, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 82 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(62, [C|Ics], Line, Tlen, _, _) when C >= 84, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(62, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 114 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(62, [C|Ics], Line, Tlen, _, _) when C >= 116, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(62, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,62};
yystate(61, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(69, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [43|Ics], Line, Tlen, Action, Alen) ->
    yystate(69, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(65, Ics, Line, Tlen+1, Action, Alen);
yystate(61, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,61};
yystate(60, [105|Ics], Line, Tlen, _, _) ->
    yystate(64, Ics, Line, Tlen+1, 24, Tlen);
yystate(60, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(60, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(60, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(60, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(60, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 104 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(60, [C|Ics], Line, Tlen, _, _) when C >= 106, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(60, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,60};
yystate(59, [114|Ics], Line, Tlen, _, _) ->
    yystate(55, Ics, Line, Tlen+1, 24, Tlen);
yystate(59, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(59, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(59, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(59, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(59, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 113 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(59, [C|Ics], Line, Tlen, _, _) when C >= 115, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(59, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,59};
yystate(58, [116|Ics], Line, Tlen, _, _) ->
    yystate(54, Ics, Line, Tlen+1, 24, Tlen);
yystate(58, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(58, [84|Ics], Line, Tlen, _, _) ->
    yystate(54, Ics, Line, Tlen+1, 24, Tlen);
yystate(58, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(58, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(58, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 83 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(58, [C|Ics], Line, Tlen, _, _) when C >= 85, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(58, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 115 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(58, [C|Ics], Line, Tlen, _, _) when C >= 117, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(58, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,58};
yystate(57, [101|Ics], Line, Tlen, _, _) ->
    yystate(61, Ics, Line, Tlen+1, 21, Tlen);
yystate(57, [69|Ics], Line, Tlen, _, _) ->
    yystate(61, Ics, Line, Tlen+1, 21, Tlen);
yystate(57, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(57, Ics, Line, Tlen+1, 21, Tlen);
yystate(57, Ics, Line, Tlen, _, _) ->
    {21,Tlen,Ics,Line,57};
yystate(56, [114|Ics], Line, Tlen, _, _) ->
    yystate(60, Ics, Line, Tlen+1, 24, Tlen);
yystate(56, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(56, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(56, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(56, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(56, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 113 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(56, [C|Ics], Line, Tlen, _, _) when C >= 115, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(56, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,56};
yystate(55, [99|Ics], Line, Tlen, _, _) ->
    yystate(51, Ics, Line, Tlen+1, 24, Tlen);
yystate(55, [97|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(55, [98|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(55, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(55, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(55, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(55, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(55, [C|Ics], Line, Tlen, _, _) when C >= 100, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(55, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,55};
yystate(54, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 2, Tlen);
yystate(54, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 2, Tlen);
yystate(54, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 2, Tlen);
yystate(54, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 2, Tlen);
yystate(54, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 2, Tlen);
yystate(54, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line,54};
yystate(53, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(53, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,53};
yystate(52, [101|Ics], Line, Tlen, _, _) ->
    yystate(4, Ics, Line, Tlen+1, 24, Tlen);
yystate(52, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(52, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(52, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(52, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(52, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(52, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(52, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,52};
yystate(51, [101|Ics], Line, Tlen, _, _) ->
    yystate(47, Ics, Line, Tlen+1, 24, Tlen);
yystate(51, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(51, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(51, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(51, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(51, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(51, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(51, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,51};
yystate(50, [110|Ics], Line, Tlen, _, _) ->
    yystate(46, Ics, Line, Tlen+1, 24, Tlen);
yystate(50, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(50, [78|Ics], Line, Tlen, _, _) ->
    yystate(46, Ics, Line, Tlen+1, 24, Tlen);
yystate(50, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(50, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(50, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 77 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(50, [C|Ics], Line, Tlen, _, _) when C >= 79, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(50, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 109 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(50, [C|Ics], Line, Tlen, _, _) when C >= 111, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(50, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,50};
yystate(49, [46|Ics], Line, Tlen, _, _) ->
    yystate(53, Ics, Line, Tlen+1, 20, Tlen);
yystate(49, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(49, Ics, Line, Tlen+1, 20, Tlen);
yystate(49, Ics, Line, Tlen, _, _) ->
    {20,Tlen,Ics,Line,49};
yystate(48, [100|Ics], Line, Tlen, _, _) ->
    yystate(52, Ics, Line, Tlen+1, 24, Tlen);
yystate(48, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(48, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(48, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(48, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(48, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 99 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(48, [C|Ics], Line, Tlen, _, _) when C >= 101, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(48, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,48};
yystate(47, [110|Ics], Line, Tlen, _, _) ->
    yystate(43, Ics, Line, Tlen+1, 24, Tlen);
yystate(47, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(47, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(47, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(47, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(47, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 109 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(47, [C|Ics], Line, Tlen, _, _) when C >= 111, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(47, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,47};
yystate(46, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 4, Tlen);
yystate(46, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 4, Tlen);
yystate(46, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 4, Tlen);
yystate(46, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 4, Tlen);
yystate(46, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 4, Tlen);
yystate(46, Ics, Line, Tlen, _, _) ->
    {4,Tlen,Ics,Line,46};
yystate(45, [115|Ics], Line, Tlen, _, _) ->
    yystate(92, Ics, Line, Tlen+1, 24, Tlen);
yystate(45, [110|Ics], Line, Tlen, _, _) ->
    yystate(96, Ics, Line, Tlen+1, 24, Tlen);
yystate(45, [103|Ics], Line, Tlen, _, _) ->
    yystate(104, Ics, Line, Tlen+1, 24, Tlen);
yystate(45, [102|Ics], Line, Tlen, _, _) ->
    yystate(110, Ics, Line, Tlen+1, 24, Tlen);
yystate(45, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(45, [83|Ics], Line, Tlen, _, _) ->
    yystate(92, Ics, Line, Tlen+1, 24, Tlen);
yystate(45, [78|Ics], Line, Tlen, _, _) ->
    yystate(96, Ics, Line, Tlen+1, 24, Tlen);
yystate(45, [71|Ics], Line, Tlen, _, _) ->
    yystate(104, Ics, Line, Tlen+1, 24, Tlen);
yystate(45, [70|Ics], Line, Tlen, _, _) ->
    yystate(110, Ics, Line, Tlen+1, 24, Tlen);
yystate(45, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(45, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(45, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 69 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(45, [C|Ics], Line, Tlen, _, _) when C >= 72, C =< 77 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(45, [C|Ics], Line, Tlen, _, _) when C >= 79, C =< 82 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(45, [C|Ics], Line, Tlen, _, _) when C >= 84, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(45, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 101 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(45, [C|Ics], Line, Tlen, _, _) when C >= 104, C =< 109 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(45, [C|Ics], Line, Tlen, _, _) when C >= 111, C =< 114 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(45, [C|Ics], Line, Tlen, _, _) when C >= 116, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(45, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,45};
yystate(44, [105|Ics], Line, Tlen, _, _) ->
    yystate(48, Ics, Line, Tlen+1, 24, Tlen);
yystate(44, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(44, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(44, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(44, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(44, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 104 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(44, [C|Ics], Line, Tlen, _, _) when C >= 106, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(44, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,44};
yystate(43, [116|Ics], Line, Tlen, _, _) ->
    yystate(39, Ics, Line, Tlen+1, 24, Tlen);
yystate(43, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(43, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(43, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(43, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(43, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 115 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(43, [C|Ics], Line, Tlen, _, _) when C >= 117, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(43, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,43};
yystate(42, [114|Ics], Line, Tlen, _, _) ->
    yystate(38, Ics, Line, Tlen+1, 24, Tlen);
yystate(42, [112|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(42, [113|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(42, [111|Ics], Line, Tlen, _, _) ->
    yystate(26, Ics, Line, Tlen+1, 24, Tlen);
yystate(42, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(42, [82|Ics], Line, Tlen, _, _) ->
    yystate(38, Ics, Line, Tlen+1, 24, Tlen);
yystate(42, [80|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(42, [81|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(42, [79|Ics], Line, Tlen, _, _) ->
    yystate(26, Ics, Line, Tlen+1, 24, Tlen);
yystate(42, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(42, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(42, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 78 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(42, [C|Ics], Line, Tlen, _, _) when C >= 83, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(42, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 110 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(42, [C|Ics], Line, Tlen, _, _) when C >= 115, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(42, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,42};
yystate(41, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 12, Tlen);
yystate(41, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 12, Tlen);
yystate(41, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 12, Tlen);
yystate(41, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 12, Tlen);
yystate(41, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 12, Tlen);
yystate(41, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,41};
yystate(40, [118|Ics], Line, Tlen, _, _) ->
    yystate(44, Ics, Line, Tlen+1, 24, Tlen);
yystate(40, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(40, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(40, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(40, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(40, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 117 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(40, [C|Ics], Line, Tlen, _, _) when C >= 119, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(40, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,40};
yystate(39, [105|Ics], Line, Tlen, _, _) ->
    yystate(35, Ics, Line, Tlen+1, 24, Tlen);
yystate(39, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(39, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(39, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(39, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(39, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 104 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(39, [C|Ics], Line, Tlen, _, _) when C >= 106, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(39, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,39};
yystate(38, [111|Ics], Line, Tlen, _, _) ->
    yystate(34, Ics, Line, Tlen+1, 24, Tlen);
yystate(38, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(38, [79|Ics], Line, Tlen, _, _) ->
    yystate(34, Ics, Line, Tlen+1, 24, Tlen);
yystate(38, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(38, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(38, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 78 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(38, [C|Ics], Line, Tlen, _, _) when C >= 80, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(38, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 110 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(38, [C|Ics], Line, Tlen, _, _) when C >= 112, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(38, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,38};
yystate(37, [101|Ics], Line, Tlen, _, _) ->
    yystate(41, Ics, Line, Tlen+1, 24, Tlen);
yystate(37, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(37, [69|Ics], Line, Tlen, _, _) ->
    yystate(41, Ics, Line, Tlen+1, 24, Tlen);
yystate(37, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(37, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(37, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 68 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(37, [C|Ics], Line, Tlen, _, _) when C >= 70, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(37, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(37, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(37, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,37};
yystate(36, [105|Ics], Line, Tlen, _, _) ->
    yystate(40, Ics, Line, Tlen+1, 19, Tlen);
yystate(36, [101|Ics], Line, Tlen, _, _) ->
    yystate(56, Ics, Line, Tlen+1, 19, Tlen);
yystate(36, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 19, Tlen);
yystate(36, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 19, Tlen);
yystate(36, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 19, Tlen);
yystate(36, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 19, Tlen);
yystate(36, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(99, Ics, Line, Tlen+1, 19, Tlen);
yystate(36, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 104 ->
    yystate(99, Ics, Line, Tlen+1, 19, Tlen);
yystate(36, [C|Ics], Line, Tlen, _, _) when C >= 106, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 19, Tlen);
yystate(36, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,36};
yystate(35, [108|Ics], Line, Tlen, _, _) ->
    yystate(31, Ics, Line, Tlen+1, 24, Tlen);
yystate(35, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(35, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(35, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(35, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(35, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 107 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(35, [C|Ics], Line, Tlen, _, _) when C >= 109, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(35, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,35};
yystate(34, [109|Ics], Line, Tlen, _, _) ->
    yystate(30, Ics, Line, Tlen+1, 24, Tlen);
yystate(34, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(34, [77|Ics], Line, Tlen, _, _) ->
    yystate(30, Ics, Line, Tlen+1, 24, Tlen);
yystate(34, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(34, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(34, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 76 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(34, [C|Ics], Line, Tlen, _, _) when C >= 78, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(34, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 108 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(34, [C|Ics], Line, Tlen, _, _) when C >= 110, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(34, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,34};
yystate(33, [114|Ics], Line, Tlen, _, _) ->
    yystate(37, Ics, Line, Tlen+1, 24, Tlen);
yystate(33, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(33, [82|Ics], Line, Tlen, _, _) ->
    yystate(37, Ics, Line, Tlen+1, 24, Tlen);
yystate(33, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(33, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(33, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 81 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(33, [C|Ics], Line, Tlen, _, _) when C >= 83, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(33, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 113 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(33, [C|Ics], Line, Tlen, _, _) when C >= 115, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(33, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,33};
yystate(32, [122|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(32, [121|Ics], Line, Tlen, _, _) ->
    yystate(12, Ics, Line, Tlen+1, 24, Tlen);
yystate(32, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(32, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(32, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(32, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(32, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 120 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(32, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,32};
yystate(31, [101|Ics], Line, Tlen, _, _) ->
    yystate(27, Ics, Line, Tlen+1, 24, Tlen);
yystate(31, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(31, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(31, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(31, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(31, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(31, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(31, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,31};
yystate(30, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 5, Tlen);
yystate(30, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 5, Tlen);
yystate(30, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 5, Tlen);
yystate(30, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 5, Tlen);
yystate(30, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 5, Tlen);
yystate(30, Ics, Line, Tlen, _, _) ->
    {5,Tlen,Ics,Line,30};
yystate(29, [111|Ics], Line, Tlen, _, _) ->
    yystate(33, Ics, Line, Tlen+1, 24, Tlen);
yystate(29, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(29, [79|Ics], Line, Tlen, _, _) ->
    yystate(33, Ics, Line, Tlen+1, 24, Tlen);
yystate(29, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(29, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(29, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 78 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(29, [C|Ics], Line, Tlen, _, _) when C >= 80, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(29, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 110 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(29, [C|Ics], Line, Tlen, _, _) when C >= 112, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(29, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,29};
yystate(28, [116|Ics], Line, Tlen, _, _) ->
    yystate(32, Ics, Line, Tlen+1, 24, Tlen);
yystate(28, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(28, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(28, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(28, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(28, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 115 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(28, [C|Ics], Line, Tlen, _, _) when C >= 117, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(28, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,28};
yystate(27, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 15, Tlen);
yystate(27, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 15, Tlen);
yystate(27, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 15, Tlen);
yystate(27, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 15, Tlen);
yystate(27, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 15, Tlen);
yystate(27, Ics, Line, Tlen, _, _) ->
    {15,Tlen,Ics,Line,27};
yystate(26, [114|Ics], Line, Tlen, _, _) ->
    yystate(22, Ics, Line, Tlen+1, 24, Tlen);
yystate(26, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(26, [82|Ics], Line, Tlen, _, _) ->
    yystate(22, Ics, Line, Tlen+1, 24, Tlen);
yystate(26, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(26, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(26, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 81 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(26, [C|Ics], Line, Tlen, _, _) when C >= 83, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(26, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 113 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(26, [C|Ics], Line, Tlen, _, _) when C >= 115, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(26, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,26};
yystate(25, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 6, Tlen);
yystate(25, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 6, Tlen);
yystate(25, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 6, Tlen);
yystate(25, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 6, Tlen);
yystate(25, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 6, Tlen);
yystate(25, Ics, Line, Tlen, _, _) ->
    {6,Tlen,Ics,Line,25};
yystate(24, [112|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 24, Tlen);
yystate(24, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(24, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(24, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(24, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(24, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 111 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(24, [C|Ics], Line, Tlen, _, _) when C >= 113, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(24, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,24};
yystate(23, [117|Ics], Line, Tlen, _, _) ->
    yystate(19, Ics, Line, Tlen+1, 19, Tlen);
yystate(23, [116|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 19, Tlen);
yystate(23, [115|Ics], Line, Tlen, _, _) ->
    yystate(103, Ics, Line, Tlen+1, 19, Tlen);
yystate(23, [105|Ics], Line, Tlen, _, _) ->
    yystate(8, Ics, Line, Tlen+1, 19, Tlen);
yystate(23, [97|Ics], Line, Tlen, _, _) ->
    yystate(16, Ics, Line, Tlen+1, 19, Tlen);
yystate(23, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 19, Tlen);
yystate(23, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 19, Tlen);
yystate(23, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 19, Tlen);
yystate(23, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 19, Tlen);
yystate(23, [C|Ics], Line, Tlen, _, _) when C >= 98, C =< 104 ->
    yystate(99, Ics, Line, Tlen+1, 19, Tlen);
yystate(23, [C|Ics], Line, Tlen, _, _) when C >= 106, C =< 114 ->
    yystate(99, Ics, Line, Tlen+1, 19, Tlen);
yystate(23, [C|Ics], Line, Tlen, _, _) when C >= 118, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 19, Tlen);
yystate(23, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,23};
yystate(22, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 13, Tlen);
yystate(22, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 13, Tlen);
yystate(22, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 13, Tlen);
yystate(22, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 13, Tlen);
yystate(22, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 13, Tlen);
yystate(22, Ics, Line, Tlen, _, _) ->
    {13,Tlen,Ics,Line,22};
yystate(21, [110|Ics], Line, Tlen, _, _) ->
    yystate(25, Ics, Line, Tlen+1, 24, Tlen);
yystate(21, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(21, [78|Ics], Line, Tlen, _, _) ->
    yystate(25, Ics, Line, Tlen+1, 24, Tlen);
yystate(21, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(21, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(21, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 77 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(21, [C|Ics], Line, Tlen, _, _) when C >= 79, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(21, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 109 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(21, [C|Ics], Line, Tlen, _, _) when C >= 111, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(21, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,21};
yystate(20, [109|Ics], Line, Tlen, _, _) ->
    yystate(24, Ics, Line, Tlen+1, 24, Tlen);
yystate(20, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(20, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(20, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(20, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(20, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 108 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(20, [C|Ics], Line, Tlen, _, _) when C >= 110, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(20, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,20};
yystate(19, [108|Ics], Line, Tlen, _, _) ->
    yystate(15, Ics, Line, Tlen+1, 24, Tlen);
yystate(19, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(19, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(19, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(19, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(19, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 107 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(19, [C|Ics], Line, Tlen, _, _) when C >= 109, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(19, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,19};
yystate(18, [117|Ics], Line, Tlen, _, _) ->
    yystate(14, Ics, Line, Tlen+1, 24, Tlen);
yystate(18, [101|Ics], Line, Tlen, _, _) ->
    yystate(5, Ics, Line, Tlen+1, 24, Tlen);
yystate(18, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(18, [85|Ics], Line, Tlen, _, _) ->
    yystate(14, Ics, Line, Tlen+1, 24, Tlen);
yystate(18, [69|Ics], Line, Tlen, _, _) ->
    yystate(5, Ics, Line, Tlen+1, 24, Tlen);
yystate(18, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(18, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(18, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 68 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(18, [C|Ics], Line, Tlen, _, _) when C >= 70, C =< 84 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(18, [C|Ics], Line, Tlen, _, _) when C >= 86, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(18, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(18, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 116 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(18, [C|Ics], Line, Tlen, _, _) when C >= 118, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(18, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,18};
yystate(17, [101|Ics], Line, Tlen, _, _) ->
    yystate(21, Ics, Line, Tlen+1, 24, Tlen);
yystate(17, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(17, [69|Ics], Line, Tlen, _, _) ->
    yystate(21, Ics, Line, Tlen+1, 24, Tlen);
yystate(17, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(17, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(17, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 68 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(17, [C|Ics], Line, Tlen, _, _) when C >= 70, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(17, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(17, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(17, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,17};
yystate(16, [121|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(16, [122|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(16, [120|Ics], Line, Tlen, _, _) ->
    yystate(12, Ics, Line, Tlen+1, 24, Tlen);
yystate(16, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(16, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(16, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(16, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(16, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 119 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(16, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,16};
yystate(15, [116|Ics], Line, Tlen, _, _) ->
    yystate(11, Ics, Line, Tlen+1, 24, Tlen);
yystate(15, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(15, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(15, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(15, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(15, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 115 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(15, [C|Ics], Line, Tlen, _, _) when C >= 117, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(15, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,15};
yystate(14, [99|Ics], Line, Tlen, _, _) ->
    yystate(10, Ics, Line, Tlen+1, 24, Tlen);
yystate(14, [97|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(14, [98|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(14, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(14, [67|Ics], Line, Tlen, _, _) ->
    yystate(10, Ics, Line, Tlen+1, 24, Tlen);
yystate(14, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(14, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(14, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 66 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(14, [C|Ics], Line, Tlen, _, _) when C >= 68, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(14, [C|Ics], Line, Tlen, _, _) when C >= 100, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(14, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,14};
yystate(13, [101|Ics], Line, Tlen, _, _) ->
    yystate(17, Ics, Line, Tlen+1, 24, Tlen);
yystate(13, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(13, [69|Ics], Line, Tlen, _, _) ->
    yystate(17, Ics, Line, Tlen+1, 24, Tlen);
yystate(13, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(13, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(13, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 68 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(13, [C|Ics], Line, Tlen, _, _) when C >= 70, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(13, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(13, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(13, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,13};
yystate(12, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 16, Tlen);
yystate(12, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 16, Tlen);
yystate(12, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 16, Tlen);
yystate(12, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 16, Tlen);
yystate(12, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 16, Tlen);
yystate(12, Ics, Line, Tlen, _, _) ->
    {16,Tlen,Ics,Line,12};
yystate(11, [105|Ics], Line, Tlen, _, _) ->
    yystate(7, Ics, Line, Tlen+1, 24, Tlen);
yystate(11, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(11, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(11, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(11, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(11, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 104 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(11, [C|Ics], Line, Tlen, _, _) when C >= 106, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(11, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,11};
yystate(10, [107|Ics], Line, Tlen, _, _) ->
    yystate(6, Ics, Line, Tlen+1, 24, Tlen);
yystate(10, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(10, [75|Ics], Line, Tlen, _, _) ->
    yystate(6, Ics, Line, Tlen+1, 24, Tlen);
yystate(10, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(10, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(10, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 74 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(10, [C|Ics], Line, Tlen, _, _) when C >= 76, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(10, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 106 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(10, [C|Ics], Line, Tlen, _, _) when C >= 108, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(10, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,10};
yystate(9, [119|Ics], Line, Tlen, _, _) ->
    yystate(13, Ics, Line, Tlen+1, 24, Tlen);
yystate(9, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(9, [87|Ics], Line, Tlen, _, _) ->
    yystate(13, Ics, Line, Tlen+1, 24, Tlen);
yystate(9, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(9, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(9, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 86 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(9, [C|Ics], Line, Tlen, _, _) when C >= 88, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(9, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 118 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(9, [C|Ics], Line, Tlen, _, _) when C >= 120, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(9, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,9};
yystate(8, [110|Ics], Line, Tlen, _, _) ->
    yystate(12, Ics, Line, Tlen+1, 24, Tlen);
yystate(8, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(8, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(8, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(8, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(8, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 109 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(8, [C|Ics], Line, Tlen, _, _) when C >= 111, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(8, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,8};
yystate(7, [112|Ics], Line, Tlen, _, _) ->
    yystate(3, Ics, Line, Tlen+1, 24, Tlen);
yystate(7, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(7, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(7, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(7, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(7, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 111 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(7, [C|Ics], Line, Tlen, _, _) when C >= 113, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(7, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,7};
yystate(6, [101|Ics], Line, Tlen, _, _) ->
    yystate(2, Ics, Line, Tlen+1, 24, Tlen);
yystate(6, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(6, [69|Ics], Line, Tlen, _, _) ->
    yystate(2, Ics, Line, Tlen+1, 24, Tlen);
yystate(6, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(6, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(6, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 68 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(6, [C|Ics], Line, Tlen, _, _) when C >= 70, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(6, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(6, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(6, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,6};
yystate(5, [116|Ics], Line, Tlen, _, _) ->
    yystate(9, Ics, Line, Tlen+1, 24, Tlen);
yystate(5, [102|Ics], Line, Tlen, _, _) ->
    yystate(29, Ics, Line, Tlen+1, 24, Tlen);
yystate(5, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(5, [84|Ics], Line, Tlen, _, _) ->
    yystate(9, Ics, Line, Tlen+1, 24, Tlen);
yystate(5, [70|Ics], Line, Tlen, _, _) ->
    yystate(29, Ics, Line, Tlen+1, 24, Tlen);
yystate(5, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(5, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(5, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 69 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(5, [C|Ics], Line, Tlen, _, _) when C >= 71, C =< 83 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(5, [C|Ics], Line, Tlen, _, _) when C >= 85, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(5, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 101 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(5, [C|Ics], Line, Tlen, _, _) when C >= 103, C =< 115 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(5, [C|Ics], Line, Tlen, _, _) when C >= 117, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(5, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,5};
yystate(4, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 17, Tlen);
yystate(4, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 17, Tlen);
yystate(4, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 17, Tlen);
yystate(4, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 17, Tlen);
yystate(4, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 17, Tlen);
yystate(4, Ics, Line, Tlen, _, _) ->
    {17,Tlen,Ics,Line,4};
yystate(3, [108|Ics], Line, Tlen, _, _) ->
    yystate(0, Ics, Line, Tlen+1, 24, Tlen);
yystate(3, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(3, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(3, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(3, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(3, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 107 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(3, [C|Ics], Line, Tlen, _, _) when C >= 109, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(3, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,3};
yystate(2, [116|Ics], Line, Tlen, _, _) ->
    yystate(1, Ics, Line, Tlen+1, 24, Tlen);
yystate(2, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(2, [84|Ics], Line, Tlen, _, _) ->
    yystate(1, Ics, Line, Tlen+1, 24, Tlen);
yystate(2, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(2, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(2, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 83 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(2, [C|Ics], Line, Tlen, _, _) when C >= 85, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(2, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 115 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(2, [C|Ics], Line, Tlen, _, _) when C >= 117, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(2, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,2};
yystate(1, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 1, Tlen);
yystate(1, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 1, Tlen);
yystate(1, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 1, Tlen);
yystate(1, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 1, Tlen);
yystate(1, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(99, Ics, Line, Tlen+1, 1, Tlen);
yystate(1, Ics, Line, Tlen, _, _) ->
    {1,Tlen,Ics,Line,1};
yystate(0, [122|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(0, [121|Ics], Line, Tlen, _, _) ->
    yystate(4, Ics, Line, Tlen+1, 24, Tlen);
yystate(0, [95|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(0, [45|Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(0, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(0, [C|Ics], Line, Tlen, _, _) when C >= 64, C =< 90 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(0, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 120 ->
    yystate(99, Ics, Line, Tlen+1, 24, Tlen);
yystate(0, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,0};
yystate(S, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,S}.

%% yyaction(Action, TokenLength, TokenChars, TokenLine) ->
%% {token,Token} | {end_token, Token} | skip_token | {error,String}.
%% Generated action function.

yyaction(0, _, _, TokenLine) ->
    yyaction_0(TokenLine);
yyaction(1, _, _, TokenLine) ->
    yyaction_1(TokenLine);
yyaction(2, _, _, TokenLine) ->
    yyaction_2(TokenLine);
yyaction(3, _, _, TokenLine) ->
    yyaction_3(TokenLine);
yyaction(4, _, _, TokenLine) ->
    yyaction_4(TokenLine);
yyaction(5, _, _, TokenLine) ->
    yyaction_5(TokenLine);
yyaction(6, _, _, TokenLine) ->
    yyaction_6(TokenLine);
yyaction(7, _, _, TokenLine) ->
    yyaction_7(TokenLine);
yyaction(8, _, _, TokenLine) ->
    yyaction_8(TokenLine);
yyaction(9, _, _, TokenLine) ->
    yyaction_9(TokenLine);
yyaction(10, _, _, TokenLine) ->
    yyaction_10(TokenLine);
yyaction(11, _, _, TokenLine) ->
    yyaction_11(TokenLine);
yyaction(12, _, _, TokenLine) ->
    yyaction_12(TokenLine);
yyaction(13, _, _, TokenLine) ->
    yyaction_13(TokenLine);
yyaction(14, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_14(TokenChars, TokenLine);
yyaction(15, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_15(TokenChars, TokenLine);
yyaction(16, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_16(TokenChars, TokenLine);
yyaction(17, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_17(TokenChars, TokenLine);
yyaction(18, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_18(TokenChars, TokenLine);
yyaction(19, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_19(TokenChars, TokenLine);
yyaction(20, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_20(TokenChars, TokenLine);
yyaction(21, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_21(TokenChars, TokenLine);
yyaction(22, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_22(TokenChars, TokenLen, TokenLine);
yyaction(23, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_23(TokenChars, TokenLen, TokenLine);
yyaction(24, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_24(TokenChars, TokenLine);
yyaction(25, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_25(TokenChars, TokenLine);
yyaction(26, _, _, _) ->
    yyaction_26();
yyaction(_, _, _, _) -> error.

-compile({inline,yyaction_0/1}).
-file("src/dql_lexer.xrl", 37).
yyaction_0(TokenLine) ->
     { token, { kw_select, TokenLine } } .

-compile({inline,yyaction_1/1}).
-file("src/dql_lexer.xrl", 38).
yyaction_1(TokenLine) ->
     { token, { kw_bucket, TokenLine } } .

-compile({inline,yyaction_2/1}).
-file("src/dql_lexer.xrl", 39).
yyaction_2(TokenLine) ->
     { token, { kw_last, TokenLine } } .

-compile({inline,yyaction_3/1}).
-file("src/dql_lexer.xrl", 40).
yyaction_3(TokenLine) ->
     { token, { kw_as, TokenLine } } .

-compile({inline,yyaction_4/1}).
-file("src/dql_lexer.xrl", 41).
yyaction_4(TokenLine) ->
     { token, { kw_in, TokenLine } } .

-compile({inline,yyaction_5/1}).
-file("src/dql_lexer.xrl", 42).
yyaction_5(TokenLine) ->
     { token, { kw_from, TokenLine } } .

-compile({inline,yyaction_6/1}).
-file("src/dql_lexer.xrl", 43).
yyaction_6(TokenLine) ->
     { token, { kw_between, TokenLine } } .

-compile({inline,yyaction_7/1}).
-file("src/dql_lexer.xrl", 44).
yyaction_7(TokenLine) ->
     { token, { kw_like, TokenLine } } .

-compile({inline,yyaction_8/1}).
-file("src/dql_lexer.xrl", 45).
yyaction_8(TokenLine) ->
     { token, { kw_now, TokenLine } } .

-compile({inline,yyaction_9/1}).
-file("src/dql_lexer.xrl", 46).
yyaction_9(TokenLine) ->
     { token, { kw_ago, TokenLine } } .

-compile({inline,yyaction_10/1}).
-file("src/dql_lexer.xrl", 47).
yyaction_10(TokenLine) ->
     { token, { kw_and, TokenLine } } .

-compile({inline,yyaction_11/1}).
-file("src/dql_lexer.xrl", 48).
yyaction_11(TokenLine) ->
     { token, { kw_after, TokenLine } } .

-compile({inline,yyaction_12/1}).
-file("src/dql_lexer.xrl", 49).
yyaction_12(TokenLine) ->
     { token, { kw_before, TokenLine } } .

-compile({inline,yyaction_13/1}).
-file("src/dql_lexer.xrl", 50).
yyaction_13(TokenLine) ->
     { token, { kw_for, TokenLine } } .

-compile({inline,yyaction_14/2}).
-file("src/dql_lexer.xrl", 52).
yyaction_14(TokenChars, TokenLine) ->
     { token, { derivate, TokenLine, a (TokenChars) } } .

-compile({inline,yyaction_15/2}).
-file("src/dql_lexer.xrl", 53).
yyaction_15(TokenChars, TokenLine) ->
     { token, { percentile, TokenLine, a (TokenChars) } } .

-compile({inline,yyaction_16/2}).
-file("src/dql_lexer.xrl", 54).
yyaction_16(TokenChars, TokenLine) ->
     { token, { aggr, TokenLine, a (TokenChars) } } .

-compile({inline,yyaction_17/2}).
-file("src/dql_lexer.xrl", 55).
yyaction_17(TokenChars, TokenLine) ->
     { token, { math, TokenLine, a (TokenChars) } } .

-compile({inline,yyaction_18/2}).
-file("src/dql_lexer.xrl", 56).
yyaction_18(TokenChars, TokenLine) ->
     { token, { caggr, TokenLine, a (TokenChars) } } .

-compile({inline,yyaction_19/2}).
-file("src/dql_lexer.xrl", 57).
yyaction_19(TokenChars, TokenLine) ->
     { token, { time, TokenLine, a (TokenChars) } } .

-compile({inline,yyaction_20/2}).
-file("src/dql_lexer.xrl", 60).
yyaction_20(TokenChars, TokenLine) ->
     { token, { integer, TokenLine, i (TokenChars) } } .

-compile({inline,yyaction_21/2}).
-file("src/dql_lexer.xrl", 61).
yyaction_21(TokenChars, TokenLine) ->
     { token, { float, TokenLine, f (TokenChars) } } .

-compile({inline,yyaction_22/3}).
-file("src/dql_lexer.xrl", 63).
yyaction_22(TokenChars, TokenLen, TokenLine) ->
     S = strip (TokenChars, TokenLen),
     { token, { part, TokenLine, b (S) } } .

-compile({inline,yyaction_23/3}).
-file("src/dql_lexer.xrl", 65).
yyaction_23(TokenChars, TokenLen, TokenLine) ->
     S = strip (TokenChars, TokenLen),
     { token, { date, TokenLine, S } } .

-compile({inline,yyaction_24/2}).
-file("src/dql_lexer.xrl", 67).
yyaction_24(TokenChars, TokenLine) ->
     { token, { name, TokenLine, b (TokenChars) } } .

-compile({inline,yyaction_25/2}).
-file("src/dql_lexer.xrl", 68).
yyaction_25(TokenChars, TokenLine) ->
     { token, { a (TokenChars), TokenLine } } .

-compile({inline,yyaction_26/0}).
-file("src/dql_lexer.xrl", 69).
yyaction_26() ->
     skip_token .

-file("/usr/local/lib/erlang/lib/parsetools-2.0.12/include/leexinc.hrl", 282).
